==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface OAuthSpecFluent<A extends OAuthSpecFluent<A>> extends Fluent<A>{
  public A addToIdentityProviders(Integer index,IdentityProvider item);
  public A setToIdentityProviders(Integer index,IdentityProvider item);
  public A addToIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... items);
  public A addAllToIdentityProviders(Collection<IdentityProvider> items);
  public A removeFromIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... items);
  public A removeAllFromIdentityProviders(Collection<IdentityProvider> items);
  public A removeMatchingFromIdentityProviders(Predicate<IdentityProviderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIdentityProviders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IdentityProvider> getIdentityProviders();
  public List<IdentityProvider> buildIdentityProviders();
  public IdentityProvider buildIdentityProvider(Integer index);
  public IdentityProvider buildFirstIdentityProvider();
  public IdentityProvider buildLastIdentityProvider();
  public IdentityProvider buildMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate);
  public Boolean hasMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate);
  public A withIdentityProviders(List<IdentityProvider> identityProviders);
  public A withIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... identityProviders);
  public Boolean hasIdentityProviders();
  public OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProvider();
  public OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProviderLike(IdentityProvider item);
  public OAuthSpecFluent.IdentityProvidersNested<A> setNewIdentityProviderLike(Integer index,IdentityProvider item);
  public OAuthSpecFluent.IdentityProvidersNested<A> editIdentityProvider(Integer index);
  public OAuthSpecFluent.IdentityProvidersNested<A> editFirstIdentityProvider();
  public OAuthSpecFluent.IdentityProvidersNested<A> editLastIdentityProvider();
  public OAuthSpecFluent.IdentityProvidersNested<A> editMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTemplates instead.
   * @return The buildable object.
   */
  @Deprecated
  public OAuthTemplates getTemplates();
  public OAuthTemplates buildTemplates();
  public A withTemplates(OAuthTemplates templates);
  public Boolean hasTemplates();
  public OAuthSpecFluent.TemplatesNested<A> withNewTemplates();
  public OAuthSpecFluent.TemplatesNested<A> withNewTemplatesLike(OAuthTemplates item);
  public OAuthSpecFluent.TemplatesNested<A> editTemplates();
  public OAuthSpecFluent.TemplatesNested<A> editOrNewTemplates();
  public OAuthSpecFluent.TemplatesNested<A> editOrNewTemplatesLike(OAuthTemplates item);
  
  /**
   * This method has been deprecated, please use method buildTokenConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public TokenConfig getTokenConfig();
  public TokenConfig buildTokenConfig();
  public A withTokenConfig(TokenConfig tokenConfig);
  public Boolean hasTokenConfig();
  public OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfig();
  public OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfigLike(TokenConfig item);
  public OAuthSpecFluent.TokenConfigNested<A> editTokenConfig();
  public OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfig();
  public OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfigLike(TokenConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface IdentityProvidersNested<N> extends Nested<N>,IdentityProviderFluent<OAuthSpecFluent.IdentityProvidersNested<N>>{
    public N and();
    public N endIdentityProvider();
    
  }
  public interface TemplatesNested<N> extends Nested<N>,OAuthTemplatesFluent<OAuthSpecFluent.TemplatesNested<N>>{
    public N and();
    public N endTemplates();
    
  }
  public interface TokenConfigNested<N> extends Nested<N>,TokenConfigFluent<OAuthSpecFluent.TokenConfigNested<N>>{
    public N and();
    public N endTokenConfig();
    
  }
  
}

==> openshift-model-config-6.7.0-sources.jar: io/fabric8/openshift/api/model/config/v1/OAuthSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface OAuthSpecFluent<A extends OAuthSpecFluent<A>> extends Fluent<A>{
  public A addToIdentityProviders(int index,IdentityProvider item);
  public A setToIdentityProviders(int index,IdentityProvider item);
  public A addToIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... items);
  public A addAllToIdentityProviders(Collection<IdentityProvider> items);
  public A removeFromIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... items);
  public A removeAllFromIdentityProviders(Collection<IdentityProvider> items);
  public A removeMatchingFromIdentityProviders(Predicate<IdentityProviderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIdentityProviders instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IdentityProvider> getIdentityProviders();
  public List<IdentityProvider> buildIdentityProviders();
  public IdentityProvider buildIdentityProvider(int index);
  public IdentityProvider buildFirstIdentityProvider();
  public IdentityProvider buildLastIdentityProvider();
  public IdentityProvider buildMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate);
  public Boolean hasMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate);
  public A withIdentityProviders(List<IdentityProvider> identityProviders);
  public A withIdentityProviders(io.fabric8.openshift.api.model.config.v1.IdentityProvider... identityProviders);
  public Boolean hasIdentityProviders();
  public OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProvider();
  public OAuthSpecFluent.IdentityProvidersNested<A> addNewIdentityProviderLike(IdentityProvider item);
  public OAuthSpecFluent.IdentityProvidersNested<A> setNewIdentityProviderLike(int index,IdentityProvider item);
  public OAuthSpecFluent.IdentityProvidersNested<A> editIdentityProvider(int index);
  public OAuthSpecFluent.IdentityProvidersNested<A> editFirstIdentityProvider();
  public OAuthSpecFluent.IdentityProvidersNested<A> editLastIdentityProvider();
  public OAuthSpecFluent.IdentityProvidersNested<A> editMatchingIdentityProvider(Predicate<IdentityProviderBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTemplates instead.
   * @return The buildable object.
   */
  @Deprecated
  public OAuthTemplates getTemplates();
  public OAuthTemplates buildTemplates();
  public A withTemplates(OAuthTemplates templates);
  public Boolean hasTemplates();
  public OAuthSpecFluent.TemplatesNested<A> withNewTemplates();
  public OAuthSpecFluent.TemplatesNested<A> withNewTemplatesLike(OAuthTemplates item);
  public OAuthSpecFluent.TemplatesNested<A> editTemplates();
  public OAuthSpecFluent.TemplatesNested<A> editOrNewTemplates();
  public OAuthSpecFluent.TemplatesNested<A> editOrNewTemplatesLike(OAuthTemplates item);
  
  /**
   * This method has been deprecated, please use method buildTokenConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public TokenConfig getTokenConfig();
  public TokenConfig buildTokenConfig();
  public A withTokenConfig(TokenConfig tokenConfig);
  public Boolean hasTokenConfig();
  public OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfig();
  public OAuthSpecFluent.TokenConfigNested<A> withNewTokenConfigLike(TokenConfig item);
  public OAuthSpecFluent.TokenConfigNested<A> editTokenConfig();
  public OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfig();
  public OAuthSpecFluent.TokenConfigNested<A> editOrNewTokenConfigLike(TokenConfig item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface IdentityProvidersNested<N> extends Nested<N>,IdentityProviderFluent<OAuthSpecFluent.IdentityProvidersNested<N>>{
    public N and();
    public N endIdentityProvider();
    
  }
  public interface TemplatesNested<N> extends Nested<N>,OAuthTemplatesFluent<OAuthSpecFluent.TemplatesNested<N>>{
    public N and();
    public N endTemplates();
    
  }
  public interface TokenConfigNested<N> extends Nested<N>,TokenConfigFluent<OAuthSpecFluent.TokenConfigNested<N>>{
    public N and();
    public N endTokenConfig();
    
  }
  
}
